#[cfg(not(target_env = "msvc"))]
use tikv_jemallocator::Jemalloc;

#[cfg(not(target_env = "msvc"))]
#[global_allocator]
static GLOBAL: Jemalloc = Jemalloc;

use std::thread;

#[tokio::main]
async fn main() {
    std::env::set_var("RUST_LOG", "info");
    env_logger::init();

    println!("Starting worker!");

    backend::worker::init_blocking();

    thread::spawn(|| {
        tokio::runtime::Runtime::new().unwrap().block_on(async {
            backend::worker::beat()
                .await
                .unwrap()
                .start()
                .await
                .unwrap();
        });
    });

    let app = backend::worker::APP.lock().unwrap();
    let app = app.as_ref().unwrap();

    app.display_pretty().await;
    app.consume_from(&[backend::worker::QUEUE_NAME])
        .await
        .unwrap();
}
